pub fn list_interfaces() -> Vec<InterfaceInfo>Expand description
Enumerate all network interfaces on this host.
Returns an empty Vec on unsupported platforms or when the OS call fails.
pub fn list_interfaces() -> Vec<InterfaceInfo>Enumerate all network interfaces on this host.
Returns an empty Vec on unsupported platforms or when the OS call fails.