slot_size_for_mtu

Function slot_size_for_mtu 

pub fn slot_size_for_mtu(mtu: usize) -> u32
Compute the slot_size required to carry a Data packet whose content can be up to mtu bytes. Mirrors spsc::slot_size_for_mtu so callers that don’t depend on the spsc submodule can still derive a correct SHM ring sizing.